# purepyodbc

![CI](https://github.com/chrisimcevoy/purepyodbc/actions/workflows/ci-ubuntu.yml/badge.svg)
![GitHub](https://img.shields.io/github/license/chrisimcevoy/purepyodbc)
![PyPI](https://img.shields.io/pypi/v/purepyodbc)

## What is this?

This is a project which aims to provide a "pure Python" implementation of ODBC.

It will eventually implement the [DB API 2.0](https://www.python.org/dev/peps/pep-0249) specification.

It may or may not end up adopting a similar public API to the well-known [pyodbc](https://github.com/mkleehammer/pyodbc).

## Why would you do a foolish thing like that?

I'll give you two reasons:

- I could use something like this myself, but it would need to be compatible with PyPy3.x and with recent editions of SQL Server (and the features thereof).
- I could learn something by doing this project.

## Why not just use {{package}}?

I refer you to [my previous answer](#Why-would-you-do-a-foolish-thing-like-that?).

## Can I use this?

I wouldn't do that if I were you. 

I mean, if you actually did, ho-ho, bwahaha! 

Ahem.

I mean, if you actually _did_, then... it would be **entirely at your own risk**.

## Can I contribute to it?

We both know you've got nothing better to do, so... why not give it a shot? The worst I can do is say no.

In all sincerity, there are bound to be people who are better-qualified than I am to do something like this. You might just be one of those people!

## What platforms does it support?

The good news is that everything that works so far works wonderfully (more or less) on my machine, for my specific use case.

The bad news? Oh... you don't _really_ want to hear the bad news, do you?
